# Generated by Django 4.2.1 on 2023-05-21 11:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0004_icecapa_historicalicecapa"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalicecapa",
            name="enjoyment",
            field=models.CharField(
                choices=[
                    ("4", "I can have <B>a lot</B> of enjoyment and pleasure"),
                    ("3", "I can have <B>quite a lot</B> of enjoyment and pleasure"),
                    ("2", "I can have <B>a little</B> enjoyment and pleasure"),
                    ("1", "I <B>cannot</B> have <B>any</B> enjoyment and pleasure"),
                ],
                max_length=5,
                verbose_name="Enjoyment and pleasure",
            ),
        ),
        migrations.AlterField(
            model_name="icecapa",
            name="enjoyment",
            field=models.CharField(
                choices=[
                    ("4", "I can have <B>a lot</B> of enjoyment and pleasure"),
                    ("3", "I can have <B>quite a lot</B> of enjoyment and pleasure"),
                    ("2", "I can have <B>a little</B> enjoyment and pleasure"),
                    ("1", "I <B>cannot</B> have <B>any</B> enjoyment and pleasure"),
                ],
                max_length=5,
                verbose_name="Enjoyment and pleasure",
            ),
        ),
    ]
