from .eq5d3l_model_admin_mixin import (
    Eq5d3lModelAdminMixin,
    eq5d3l_fieldsets,
    eq5d3l_radio_fields,
)
from .icecapa_model_admin_mixin import (
    IcecapaModelAdminMixin,
    icecapa_fieldsets,
    icecapa_radio_fields,
)
