# Generated by Django 4.2.1 on 2023-07-07 19:32

import django.db.models.manager
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0006_alter_eq5d3l_options_alter_icecapa_options_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="eq5d3l",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="icecapa",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="sf12",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]
