# Generated by Django 4.2.4 on 2023-08-23 15:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0008_alter_eq5d3l_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_calm_peaceful",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt calm & peaceful?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_down",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt down-hearted and blue?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_lot_energy",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Did you have a lot of energy?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_calm_peaceful",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt calm & peaceful?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_down",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt down-hearted and blue?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_lot_energy",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Did you have a lot of energy?",
            ),
        ),
    ]
